==> slap-react-native-toggle-1.0.4.tgz: package/components/Utils.js <==
import Meteor, { Accounts } from 'react-native-meteor';
import moment from 'moment';
import { Notifications } from 'expo';
import { NavigationActions } from 'react-navigation';
import _ from 'lodash';

export default class Utils {
  static getFormattedPrice = (amount, unit = '원') => {
    return parseInt(amount).toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',') + unit;
  };

  static getFormattedDate = (date) => {
    if (moment().diff(moment(date), 'days') < 5) {
      return moment(date).fromNow();
    }
    else {
      return moment(date).format('YYYY-MM-DD HH:mm');
    }
  };

  static getAge = (birthYear) => {
    return (moment().year() - birthYear + 1).toString();
  };

  static sendSms = (phoneNumber, message) => {
    return Meteor.call('sendSms', phoneNumber, message);
  };

  static sendRemoteNotification = (to, title, content) => {
    return Meteor.call('sendRemoteNotification', to, title, content);
  };

  static uploadImage = (data, callback) => {
    Meteor.call('uploadImage', data, callback);
  };

  static createUser = (options, callback) => {
    Accounts.createUser(options, (error) => {
      if (error) {
        if (error.reason == 'Email already exists.') {
          error.reason = '이미 존재하는 이메일입니다.';
        }
      }

      callback(error);
    });
  };

  static signIn = (email, password, callback) => {
    Meteor.loginWithPassword(email, password, async (error) => {
      if (error) {
        if (error.reason == 'User not found') {
          error.reason = '존재하지 않는 이메일입니다.';
        }
        else if (error.reason == 'Incorrect password') {
          error.reason = '비밀번호가 틀립니다.';
        }

        callback(error);

        return;
      }

      if (!Meteor.user().profile.isActive) {
        Meteor.logout();

        callback(new Meteor.Error('정지된 계정입니다.', '정지된 계정입니다.'));

        return;
      }

      const remoteNotificationToken = await Notifications.getExpoPushTokenAsync();

      Meteor.call('users.addToSetRemoteNotificationToken', remoteNotificationToken, callback);
    });
  };

  static reset = (navigation, to, params) => {
    const resetAction = NavigationActions.reset({
      index: 0,
      actions: [
        NavigationActions.navigate({
          routeName: to,
          params: params
        })
      ]
    });

    navigation.dispatch(resetAction);
  };

  static signOut = async (callback) => {
    const remoteNotificationToken = await Notifications.getExpoPushTokenAsync();

    Meteor.call('users.pullRemoteNotificationToken', remoteNotificationToken, (error) => {
      if (error) {
        callback(error);

        return;
      }

      Meteor.logout(callback);
    });
  };

  static deleteAccount = (keyWillBeDeleted = {}, callback) => {
    const modifier = {
      'profile.isDeleted': true,
      'emails.0.address': `${Meteor.user().profile.email}_deleted`,
      'profile.email': `${Meteor.user().profile.email}_deleted`,
      'profile.remoteNotificationTokens': []
    };

    _.extend(modifier, keyWillBeDeleted);

    Meteor.call('users.update', {
      $set: modifier
    }, callback);
  };
}

==> slap-react-native-toggle-3.0.3.tgz: package/components/Utils.js <==
import { Alert } from 'react-native';
import Meteor, { Accounts } from 'react-native-meteor';
import moment from 'moment';
import { NavigationActions } from 'react-navigation';
import _ from 'lodash';
import OneSignal from 'react-native-onesignal';
import uuidV1 from 'uuid/v1';

export default class Utils {
  static alert = (content, onConfirm = () => {}) => {
    Alert.alert(null, content, [{ text: '확인', onPress: onConfirm }]);
  };

  static confirm = (content, onConfirm = () => {}, onCancel = () => {}) => {
    Alert.alert(null, content, [{ text: '취소', onPress: onCancel }, { text: '확인', onPress: onConfirm }]);
  };

  static getFormattedPrice = (amount, unit = '원') => {
    return parseInt(amount).toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',') + unit;
  };

  static getFormattedDate = (date) => {
    if (moment().diff(moment(date), 'days') < 5) {
      return moment(date).fromNow();
    }
    else {
      return moment(date).format('YYYY-MM-DD HH:mm');
    }
  };

  static getAge = (birthYear) => {
    return (moment().year() - birthYear + 1).toString();
  };

  static createUser = (options, callback) => {
    Accounts.createUser(options, (error) => {
      if (error) {
        if (error.reason == 'Email already exists.') {
          error.reason = '이미 존재하는 이메일입니다.';
        }
      }

      callback(error);
    });
  };

  static signIn = (email, password, callback) => {
    Meteor.loginWithPassword(email, password, async (error) => {
      if (error) {
        if (error.reason == 'User not found') {
          error.reason = '존재하지 않는 이메일입니다.';
        }
        else if (error.reason == 'Incorrect password') {
          error.reason = '비밀번호가 틀립니다.';
        }

        callback(error);

        return;
      }

      OneSignal.sendTag('id', Meteor.userId());

      callback();
    });
  };

  static reset = (to, navigation, params = {}) => {
    const resetAction = NavigationActions.reset({
      index: 0,
      actions: [
        NavigationActions.navigate({
          routeName: to,
          params: params
        })
      ]
    });

    navigation.dispatch(resetAction);
  };

  static signOut = (callback) => {
    OneSignal.sendTag('id', '');

    Meteor.logout(callback);
  };

  static deleteAccount = (keyBeingUpdated = {}, callback) => {
    OneSignal.sendTag('id', '');

    const uuid = uuidV1();

    const modifier = {
      'profile.isDeleted': true,
      username: `${Meteor.user().username}_${uuid}`,
      'emails.0.address': `${Meteor.user().emails[0].address}_${uuid}`,
      'profile.email': `${Meteor.user().profile.email}_${uuid}`
    };

    _.extend(modifier, keyBeingUpdated);

    Meteor.call('users.update', {
      $set: modifier
    }, callback);
  };
}
